# covidbr
<div align='center'>

<img height='400' width='400' src='https://raw.githubusercontent.com/gpftc/covid_br/main/covidbr/img/covidbr_logo.png'>
<br/>

<a href="https://github.com/perseu912"><img title="Autor" src="https://img.shields.io/badge/Autor-reynan_br-blue.svg?style=for-the-badge&logo=github"></a>
<br>
<p>
<a href='http://dgp.cnpq.br/dgp/espelhogrupo/0180330616769073'><img src='https://shields.io/badge/cnpq-grupo_de_fisica_computacional_ifsertao--pe-blueviolet?logo=appveyor&style=for-the-badge'></a>
</p>
<b> Library for data mining about covid-19 in Brazilian cities</b>
</div>

##